@@ -2,7 +2,6 @@ package WebService::Slack::WebApi;
 use strict;
 use warnings;
 use utf8;
-use 5.10.0;
 
 use Class::Load qw/ load_class /;
 use Class::Accessor::Lite::Lazy (
@@ -13,7 +12,7 @@ use Class::Accessor::Lite::Lazy (
 
 use WebService::Slack::WebApi::Client;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub _build_client {
     my $self = shift;
@@ -59,7 +58,7 @@ WebService::Slack::WebApi - a simple wrapper for Slack Web API
         channel  => 'channel id', # required
         text     => 'hoge',       # required (not required if 'attachments' argument exists)
         username => 'fuga',       # optional
-        # othre optional parameters...
+        # other optional parameters...
     );
 
 =head1 DESCRIPTION
