@@ -2,7 +2,6 @@ package WebService::Slack::WebApi::Users;
 use strict;
 use warnings;
 use utf8;
-use 5.10.0;
 
 use parent 'WebService::Slack::WebApi::Base';
 
@@ -10,6 +9,7 @@ use WebService::Slack::WebApi::Generator (
     get_presence => {
         user => 'Str',
     },
+    identity     => +{},
     info => {
         user => 'Str',
     },
